@@ -1,3 +1,4 @@
+import datetime
 import os
 
 import brian2
@@ -11,8 +12,20 @@ version = input('Enter new Brian2 version number: ').strip()
 # Run script to update codemeta.json
 os.system(f'python {basedir}/.codemeta/create_codemeta.py {version}')
 
+# Set version and release date in CITATION.cff
+new_lines = []
+with open(f'{basedir}/CITATION.cff', 'r') as f:
+    for line in f:
+        if line.startswith('version: '):
+            line = f"version: '{version}'\n"
+        if line.startswith('date-released: '):
+            line = f"date-released: '{datetime.date.today().isoformat()}'\n"
+        new_lines.append(line)
+with open(f'{basedir}/CITATION.cff', 'w') as f:
+    f.writelines(new_lines)
+
 # commit
-os.system(f'git add {basedir}/codemeta.json && git commit -m "***** Release Brian2 {version} *****"')
+os.system(f'git add {basedir}/codemeta.json && git add {basedir}/CITATION.cff && git commit -m "***** Release Brian2 {version} *****"')
 # add tag
 os.system(f'git tag -a -m "Release Brian2 {version}" {version}')
 
